% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/BioMM.R
\name{BioMMstage1pca}
\alias{BioMMstage1pca}
\title{Reconstruct stage-2 data by PCA}
\usage{
BioMMstage1pca(trainDataList, testDataList, typeMode = "regular",
  topPC = 1, innerCore = MulticoreParam(), outFileA = NULL,
  outFileB = NULL)
}
\arguments{
\item{trainDataList}{The input training data list containing ordered 
collections of matrices.}

\item{testDataList}{The input test data list containing ordered collections 
of matrices.}

\item{typeMode}{The type of PCA prediction mode. Available options are 
c('regular', 'sparse'). 
(Default: regular)}

\item{topPC}{The number of top PCs selected. The default is 1, 
i.e. the first PC.}

\item{innerCore}{The number of cores used for computation.}

\item{outFileA}{The file name of stage-2 training data with the '.rds' file 
extension.
If it's provided, then the result will be saved in this file. 
The default is NULL.}

\item{outFileB}{The file name of stage-2 training data with the '.rds' file 
extension. If it's provided, then the result will be saved in this file. 
The default is NULL.}
}
\value{
The predicted stage-2 training data and also stage-2 test data if 
'testDataList' provided. If outFileA and outFileB are provided then the 
results will be stored in the files.
}
\description{
Stage-2 data reconstruction by regular or sparse constrained principal 
component analysis (PCA).
}
\examples{
 
## Load data  
methylfile <- system.file('extdata', 'methylData.rds', package='BioMM')  
methylData <- readRDS(methylfile)    
## Annotation files for Mapping CpGs into chromosome  
probeAnnoFile <- system.file('extdata', 'cpgAnno.rds', package='BioMM')  
probeAnno <- readRDS(file=probeAnnoFile)  
## Mapping CpGs into Chromosome
dataList <- omics2chrlist(data=methylData, probeAnno)
length(dataList) 
library(BiocParallel)
param <- MulticoreParam(workers = 10) 
stage2data <- BioMMstage1pca(trainDataList=dataList, testDataList=NULL, 
                             typeMode='regular', topPC=1,  
                             innerCore=param, outFileA=NULL, outFileB=NULL) 
print(dim(stage2data))
print(head(stage2data[,1:5]))
}
\author{
Junfang Chen
}
